/** 
 *
 *   Common stdio function implementation.
 *
 *   (c) Copyright 2004 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#ifndef _MY_STDIO_H
#define _MY_STDIO_H

#include <stdio.h>
#include <syslog.h>

extern int verbose_flag;
extern int syslog_flag;

#undef PVERB
#ifdef VERBOSE_MODE
#  define PERR 1
#  define PWARN  2
#  define PINFO  4
#  define PVERB(level, fmt, args...) \
   if(verbose_flag & level) fprintf(stderr, fmt, ## args)
#else
#  define PVERB(level, fmt, args...)
#endif

#undef SYSLOG
#ifdef VERBOSE_MODE
#  define SYSLOG(type, fmt, args...) {                            \
        int __level_;                                             \
        if(syslog_flag) syslog(type, fmt, ## args);               \
	switch( type ) {					  \
	case LOG_EMERG:   /* system is unusable */		  \
	case LOG_ERR:     /* error conditions */		  \
	case LOG_CRIT:    /* critical conditions */		  \
	case LOG_ALERT:   /* action must be taken immediately */  \
		__level_ = PERR; 			          \
		break;						  \
	case LOG_WARNING: /* warning conditions */		  \
		__level_ = PWARN;			          \
		break;						  \
	case LOG_NOTICE:  /* normal, but significant, condition */\
	case LOG_INFO:    /* informational message */		  \
	case LOG_DEBUG:   /* debug-level mess */		  \
        default:                                                  \
		__level_ = PINFO;			          \
		break;						  \
	}                                                         \
	PVERB(__level_, fmt, ## args);	 		          \
	PVERB(__level_, "\n"); 			                  \
}
#else
#  define SYSLOG(type, fmt, args...) if(log_flag) syslog(type, fmt, ## args);
#endif



#ifndef WHITESPACE
#define WHITESPACE(c) (((c) == ' ') || ((c) == '\t'))
#endif


int fd_printf(int fd, const char *fmt, ...);
char * stripwhite (char *string);
int grid_norm(double f, int norm);

#endif  /* ifndef _MY_STDIO_H */
